# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AutoGroupingRuleArgs', 'AutoGroupingRule']

@pulumi.input_type
class AutoGroupingRuleArgs:
    def __init__(__self__, *,
                 rule_contents: pulumi.Input[Sequence[pulumi.Input['AutoGroupingRuleRuleContentArgs']]],
                 rule_name: pulumi.Input[builtins.str],
                 rule_type: pulumi.Input[builtins.str],
                 exclude_region_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 exclude_resource_group_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 exclude_resource_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 exclude_resource_types_scope: Optional[pulumi.Input[builtins.str]] = None,
                 region_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 resource_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 resource_types_scope: Optional[pulumi.Input[builtins.str]] = None,
                 rule_desc: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a AutoGroupingRule resource.
        :param pulumi.Input[Sequence[pulumi.Input['AutoGroupingRuleRuleContentArgs']]] rule_contents: The content records of the rule. See `rule_contents` below.
        :param pulumi.Input[builtins.str] rule_name: The name of the rule.
        :param pulumi.Input[builtins.str] rule_type: The type of the rule. Valid values:
        :param pulumi.Input[builtins.str] exclude_region_ids_scope: The IDs of regions to be excluded. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] exclude_resource_group_ids_scope: The IDs of resource groups to be excluded. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] exclude_resource_ids_scope: The IDs of resources to be excluded. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] exclude_resource_types_scope: The resource types to be excluded. Separate multiple resource types with commas (,).
        :param pulumi.Input[builtins.str] region_ids_scope: The IDs of regions. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] resource_group_ids_scope: The IDs of resource groups. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] resource_ids_scope: The IDs of resources. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] resource_types_scope: The resource types. Separate multiple resource types with commas (,).
        :param pulumi.Input[builtins.str] rule_desc: The description of the rule.
        """
        pulumi.set(__self__, "rule_contents", rule_contents)
        pulumi.set(__self__, "rule_name", rule_name)
        pulumi.set(__self__, "rule_type", rule_type)
        if exclude_region_ids_scope is not None:
            pulumi.set(__self__, "exclude_region_ids_scope", exclude_region_ids_scope)
        if exclude_resource_group_ids_scope is not None:
            pulumi.set(__self__, "exclude_resource_group_ids_scope", exclude_resource_group_ids_scope)
        if exclude_resource_ids_scope is not None:
            pulumi.set(__self__, "exclude_resource_ids_scope", exclude_resource_ids_scope)
        if exclude_resource_types_scope is not None:
            pulumi.set(__self__, "exclude_resource_types_scope", exclude_resource_types_scope)
        if region_ids_scope is not None:
            pulumi.set(__self__, "region_ids_scope", region_ids_scope)
        if resource_group_ids_scope is not None:
            pulumi.set(__self__, "resource_group_ids_scope", resource_group_ids_scope)
        if resource_ids_scope is not None:
            pulumi.set(__self__, "resource_ids_scope", resource_ids_scope)
        if resource_types_scope is not None:
            pulumi.set(__self__, "resource_types_scope", resource_types_scope)
        if rule_desc is not None:
            pulumi.set(__self__, "rule_desc", rule_desc)

    @property
    @pulumi.getter(name="ruleContents")
    def rule_contents(self) -> pulumi.Input[Sequence[pulumi.Input['AutoGroupingRuleRuleContentArgs']]]:
        """
        The content records of the rule. See `rule_contents` below.
        """
        return pulumi.get(self, "rule_contents")

    @rule_contents.setter
    def rule_contents(self, value: pulumi.Input[Sequence[pulumi.Input['AutoGroupingRuleRuleContentArgs']]]):
        pulumi.set(self, "rule_contents", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the rule.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="ruleType")
    def rule_type(self) -> pulumi.Input[builtins.str]:
        """
        The type of the rule. Valid values:
        """
        return pulumi.get(self, "rule_type")

    @rule_type.setter
    def rule_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "rule_type", value)

    @property
    @pulumi.getter(name="excludeRegionIdsScope")
    def exclude_region_ids_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IDs of regions to be excluded. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "exclude_region_ids_scope")

    @exclude_region_ids_scope.setter
    def exclude_region_ids_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exclude_region_ids_scope", value)

    @property
    @pulumi.getter(name="excludeResourceGroupIdsScope")
    def exclude_resource_group_ids_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IDs of resource groups to be excluded. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "exclude_resource_group_ids_scope")

    @exclude_resource_group_ids_scope.setter
    def exclude_resource_group_ids_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exclude_resource_group_ids_scope", value)

    @property
    @pulumi.getter(name="excludeResourceIdsScope")
    def exclude_resource_ids_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IDs of resources to be excluded. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "exclude_resource_ids_scope")

    @exclude_resource_ids_scope.setter
    def exclude_resource_ids_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exclude_resource_ids_scope", value)

    @property
    @pulumi.getter(name="excludeResourceTypesScope")
    def exclude_resource_types_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The resource types to be excluded. Separate multiple resource types with commas (,).
        """
        return pulumi.get(self, "exclude_resource_types_scope")

    @exclude_resource_types_scope.setter
    def exclude_resource_types_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exclude_resource_types_scope", value)

    @property
    @pulumi.getter(name="regionIdsScope")
    def region_ids_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IDs of regions. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "region_ids_scope")

    @region_ids_scope.setter
    def region_ids_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region_ids_scope", value)

    @property
    @pulumi.getter(name="resourceGroupIdsScope")
    def resource_group_ids_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IDs of resource groups. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "resource_group_ids_scope")

    @resource_group_ids_scope.setter
    def resource_group_ids_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_ids_scope", value)

    @property
    @pulumi.getter(name="resourceIdsScope")
    def resource_ids_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IDs of resources. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "resource_ids_scope")

    @resource_ids_scope.setter
    def resource_ids_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_ids_scope", value)

    @property
    @pulumi.getter(name="resourceTypesScope")
    def resource_types_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The resource types. Separate multiple resource types with commas (,).
        """
        return pulumi.get(self, "resource_types_scope")

    @resource_types_scope.setter
    def resource_types_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_types_scope", value)

    @property
    @pulumi.getter(name="ruleDesc")
    def rule_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the rule.
        """
        return pulumi.get(self, "rule_desc")

    @rule_desc.setter
    def rule_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_desc", value)


@pulumi.input_type
class _AutoGroupingRuleState:
    def __init__(__self__, *,
                 exclude_region_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 exclude_resource_group_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 exclude_resource_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 exclude_resource_types_scope: Optional[pulumi.Input[builtins.str]] = None,
                 region_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 resource_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 resource_types_scope: Optional[pulumi.Input[builtins.str]] = None,
                 rule_contents: Optional[pulumi.Input[Sequence[pulumi.Input['AutoGroupingRuleRuleContentArgs']]]] = None,
                 rule_desc: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 rule_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering AutoGroupingRule resources.
        :param pulumi.Input[builtins.str] exclude_region_ids_scope: The IDs of regions to be excluded. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] exclude_resource_group_ids_scope: The IDs of resource groups to be excluded. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] exclude_resource_ids_scope: The IDs of resources to be excluded. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] exclude_resource_types_scope: The resource types to be excluded. Separate multiple resource types with commas (,).
        :param pulumi.Input[builtins.str] region_ids_scope: The IDs of regions. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] resource_group_ids_scope: The IDs of resource groups. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] resource_ids_scope: The IDs of resources. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] resource_types_scope: The resource types. Separate multiple resource types with commas (,).
        :param pulumi.Input[Sequence[pulumi.Input['AutoGroupingRuleRuleContentArgs']]] rule_contents: The content records of the rule. See `rule_contents` below.
        :param pulumi.Input[builtins.str] rule_desc: The description of the rule.
        :param pulumi.Input[builtins.str] rule_name: The name of the rule.
        :param pulumi.Input[builtins.str] rule_type: The type of the rule. Valid values:
        """
        if exclude_region_ids_scope is not None:
            pulumi.set(__self__, "exclude_region_ids_scope", exclude_region_ids_scope)
        if exclude_resource_group_ids_scope is not None:
            pulumi.set(__self__, "exclude_resource_group_ids_scope", exclude_resource_group_ids_scope)
        if exclude_resource_ids_scope is not None:
            pulumi.set(__self__, "exclude_resource_ids_scope", exclude_resource_ids_scope)
        if exclude_resource_types_scope is not None:
            pulumi.set(__self__, "exclude_resource_types_scope", exclude_resource_types_scope)
        if region_ids_scope is not None:
            pulumi.set(__self__, "region_ids_scope", region_ids_scope)
        if resource_group_ids_scope is not None:
            pulumi.set(__self__, "resource_group_ids_scope", resource_group_ids_scope)
        if resource_ids_scope is not None:
            pulumi.set(__self__, "resource_ids_scope", resource_ids_scope)
        if resource_types_scope is not None:
            pulumi.set(__self__, "resource_types_scope", resource_types_scope)
        if rule_contents is not None:
            pulumi.set(__self__, "rule_contents", rule_contents)
        if rule_desc is not None:
            pulumi.set(__self__, "rule_desc", rule_desc)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if rule_type is not None:
            pulumi.set(__self__, "rule_type", rule_type)

    @property
    @pulumi.getter(name="excludeRegionIdsScope")
    def exclude_region_ids_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IDs of regions to be excluded. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "exclude_region_ids_scope")

    @exclude_region_ids_scope.setter
    def exclude_region_ids_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exclude_region_ids_scope", value)

    @property
    @pulumi.getter(name="excludeResourceGroupIdsScope")
    def exclude_resource_group_ids_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IDs of resource groups to be excluded. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "exclude_resource_group_ids_scope")

    @exclude_resource_group_ids_scope.setter
    def exclude_resource_group_ids_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exclude_resource_group_ids_scope", value)

    @property
    @pulumi.getter(name="excludeResourceIdsScope")
    def exclude_resource_ids_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IDs of resources to be excluded. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "exclude_resource_ids_scope")

    @exclude_resource_ids_scope.setter
    def exclude_resource_ids_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exclude_resource_ids_scope", value)

    @property
    @pulumi.getter(name="excludeResourceTypesScope")
    def exclude_resource_types_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The resource types to be excluded. Separate multiple resource types with commas (,).
        """
        return pulumi.get(self, "exclude_resource_types_scope")

    @exclude_resource_types_scope.setter
    def exclude_resource_types_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exclude_resource_types_scope", value)

    @property
    @pulumi.getter(name="regionIdsScope")
    def region_ids_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IDs of regions. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "region_ids_scope")

    @region_ids_scope.setter
    def region_ids_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region_ids_scope", value)

    @property
    @pulumi.getter(name="resourceGroupIdsScope")
    def resource_group_ids_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IDs of resource groups. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "resource_group_ids_scope")

    @resource_group_ids_scope.setter
    def resource_group_ids_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_ids_scope", value)

    @property
    @pulumi.getter(name="resourceIdsScope")
    def resource_ids_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IDs of resources. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "resource_ids_scope")

    @resource_ids_scope.setter
    def resource_ids_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_ids_scope", value)

    @property
    @pulumi.getter(name="resourceTypesScope")
    def resource_types_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The resource types. Separate multiple resource types with commas (,).
        """
        return pulumi.get(self, "resource_types_scope")

    @resource_types_scope.setter
    def resource_types_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_types_scope", value)

    @property
    @pulumi.getter(name="ruleContents")
    def rule_contents(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AutoGroupingRuleRuleContentArgs']]]]:
        """
        The content records of the rule. See `rule_contents` below.
        """
        return pulumi.get(self, "rule_contents")

    @rule_contents.setter
    def rule_contents(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AutoGroupingRuleRuleContentArgs']]]]):
        pulumi.set(self, "rule_contents", value)

    @property
    @pulumi.getter(name="ruleDesc")
    def rule_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the rule.
        """
        return pulumi.get(self, "rule_desc")

    @rule_desc.setter
    def rule_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_desc", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the rule.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="ruleType")
    def rule_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of the rule. Valid values:
        """
        return pulumi.get(self, "rule_type")

    @rule_type.setter
    def rule_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_type", value)


@pulumi.type_token("alicloud:resourcemanager/autoGroupingRule:AutoGroupingRule")
class AutoGroupingRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 exclude_region_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 exclude_resource_group_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 exclude_resource_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 exclude_resource_types_scope: Optional[pulumi.Input[builtins.str]] = None,
                 region_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 resource_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 resource_types_scope: Optional[pulumi.Input[builtins.str]] = None,
                 rule_contents: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AutoGroupingRuleRuleContentArgs', 'AutoGroupingRuleRuleContentArgsDict']]]]] = None,
                 rule_desc: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 rule_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Resource Manager Auto Grouping Rule resource.

        Auto grouping rules of resource group.

        For information about Resource Manager Auto Grouping Rule and how to use it, see [What is Auto Grouping Rule](https://www.alibabacloud.com/help/en/resource-management/resource-group/developer-reference/api-resourcemanager-2020-03-31-createautogroupingrule-rg).

        > **NOTE:** Available since v1.246.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.resourcemanager.AutoGroupingRule("default",
            rule_contents=[{
                "target_resource_group_condition": \"\"\"    {
                "children": [
              {
                "desired": "rg-aek*****sbvy",
                "featurePath": "$.resourceGroupId",
                "featureSource": "RESOURCE",
                "operator": "StringEquals"
              }
                ],
                "operator": "and"
            }
        \"\"\",
                "auto_grouping_scope_condition": \"\"\"    {
                "children": [
              {
                "desired": "name_a",
                "featurePath": "$.resourceName",
                "featureSource": "RESOURCE",
                "operator": "StringEqualsAny"
              }
                ],
                "operator": "and"
            }
        \"\"\",
            }],
            rule_desc=name,
            rule_type="custom_condition",
            region_ids_scope="cn-hangzhou,cn-shanghai",
            resource_ids_scope="imock-xxxxxx",
            resource_group_ids_scope="rg-aek22*****3sbvz",
            resource_types_scope="ecs.instance,vpc.vpc",
            rule_name=name)
        ```

        ## Import

        Resource Manager Auto Grouping Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:resourcemanager/autoGroupingRule:AutoGroupingRule example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] exclude_region_ids_scope: The IDs of regions to be excluded. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] exclude_resource_group_ids_scope: The IDs of resource groups to be excluded. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] exclude_resource_ids_scope: The IDs of resources to be excluded. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] exclude_resource_types_scope: The resource types to be excluded. Separate multiple resource types with commas (,).
        :param pulumi.Input[builtins.str] region_ids_scope: The IDs of regions. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] resource_group_ids_scope: The IDs of resource groups. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] resource_ids_scope: The IDs of resources. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] resource_types_scope: The resource types. Separate multiple resource types with commas (,).
        :param pulumi.Input[Sequence[pulumi.Input[Union['AutoGroupingRuleRuleContentArgs', 'AutoGroupingRuleRuleContentArgsDict']]]] rule_contents: The content records of the rule. See `rule_contents` below.
        :param pulumi.Input[builtins.str] rule_desc: The description of the rule.
        :param pulumi.Input[builtins.str] rule_name: The name of the rule.
        :param pulumi.Input[builtins.str] rule_type: The type of the rule. Valid values:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AutoGroupingRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Resource Manager Auto Grouping Rule resource.

        Auto grouping rules of resource group.

        For information about Resource Manager Auto Grouping Rule and how to use it, see [What is Auto Grouping Rule](https://www.alibabacloud.com/help/en/resource-management/resource-group/developer-reference/api-resourcemanager-2020-03-31-createautogroupingrule-rg).

        > **NOTE:** Available since v1.246.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.resourcemanager.AutoGroupingRule("default",
            rule_contents=[{
                "target_resource_group_condition": \"\"\"    {
                "children": [
              {
                "desired": "rg-aek*****sbvy",
                "featurePath": "$.resourceGroupId",
                "featureSource": "RESOURCE",
                "operator": "StringEquals"
              }
                ],
                "operator": "and"
            }
        \"\"\",
                "auto_grouping_scope_condition": \"\"\"    {
                "children": [
              {
                "desired": "name_a",
                "featurePath": "$.resourceName",
                "featureSource": "RESOURCE",
                "operator": "StringEqualsAny"
              }
                ],
                "operator": "and"
            }
        \"\"\",
            }],
            rule_desc=name,
            rule_type="custom_condition",
            region_ids_scope="cn-hangzhou,cn-shanghai",
            resource_ids_scope="imock-xxxxxx",
            resource_group_ids_scope="rg-aek22*****3sbvz",
            resource_types_scope="ecs.instance,vpc.vpc",
            rule_name=name)
        ```

        ## Import

        Resource Manager Auto Grouping Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:resourcemanager/autoGroupingRule:AutoGroupingRule example <id>
        ```

        :param str resource_name: The name of the resource.
        :param AutoGroupingRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AutoGroupingRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 exclude_region_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 exclude_resource_group_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 exclude_resource_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 exclude_resource_types_scope: Optional[pulumi.Input[builtins.str]] = None,
                 region_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 resource_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
                 resource_types_scope: Optional[pulumi.Input[builtins.str]] = None,
                 rule_contents: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AutoGroupingRuleRuleContentArgs', 'AutoGroupingRuleRuleContentArgsDict']]]]] = None,
                 rule_desc: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 rule_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AutoGroupingRuleArgs.__new__(AutoGroupingRuleArgs)

            __props__.__dict__["exclude_region_ids_scope"] = exclude_region_ids_scope
            __props__.__dict__["exclude_resource_group_ids_scope"] = exclude_resource_group_ids_scope
            __props__.__dict__["exclude_resource_ids_scope"] = exclude_resource_ids_scope
            __props__.__dict__["exclude_resource_types_scope"] = exclude_resource_types_scope
            __props__.__dict__["region_ids_scope"] = region_ids_scope
            __props__.__dict__["resource_group_ids_scope"] = resource_group_ids_scope
            __props__.__dict__["resource_ids_scope"] = resource_ids_scope
            __props__.__dict__["resource_types_scope"] = resource_types_scope
            if rule_contents is None and not opts.urn:
                raise TypeError("Missing required property 'rule_contents'")
            __props__.__dict__["rule_contents"] = rule_contents
            __props__.__dict__["rule_desc"] = rule_desc
            if rule_name is None and not opts.urn:
                raise TypeError("Missing required property 'rule_name'")
            __props__.__dict__["rule_name"] = rule_name
            if rule_type is None and not opts.urn:
                raise TypeError("Missing required property 'rule_type'")
            __props__.__dict__["rule_type"] = rule_type
        super(AutoGroupingRule, __self__).__init__(
            'alicloud:resourcemanager/autoGroupingRule:AutoGroupingRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            exclude_region_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
            exclude_resource_group_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
            exclude_resource_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
            exclude_resource_types_scope: Optional[pulumi.Input[builtins.str]] = None,
            region_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
            resource_group_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
            resource_ids_scope: Optional[pulumi.Input[builtins.str]] = None,
            resource_types_scope: Optional[pulumi.Input[builtins.str]] = None,
            rule_contents: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AutoGroupingRuleRuleContentArgs', 'AutoGroupingRuleRuleContentArgsDict']]]]] = None,
            rule_desc: Optional[pulumi.Input[builtins.str]] = None,
            rule_name: Optional[pulumi.Input[builtins.str]] = None,
            rule_type: Optional[pulumi.Input[builtins.str]] = None) -> 'AutoGroupingRule':
        """
        Get an existing AutoGroupingRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] exclude_region_ids_scope: The IDs of regions to be excluded. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] exclude_resource_group_ids_scope: The IDs of resource groups to be excluded. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] exclude_resource_ids_scope: The IDs of resources to be excluded. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] exclude_resource_types_scope: The resource types to be excluded. Separate multiple resource types with commas (,).
        :param pulumi.Input[builtins.str] region_ids_scope: The IDs of regions. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] resource_group_ids_scope: The IDs of resource groups. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] resource_ids_scope: The IDs of resources. Separate multiple IDs with commas (,).
        :param pulumi.Input[builtins.str] resource_types_scope: The resource types. Separate multiple resource types with commas (,).
        :param pulumi.Input[Sequence[pulumi.Input[Union['AutoGroupingRuleRuleContentArgs', 'AutoGroupingRuleRuleContentArgsDict']]]] rule_contents: The content records of the rule. See `rule_contents` below.
        :param pulumi.Input[builtins.str] rule_desc: The description of the rule.
        :param pulumi.Input[builtins.str] rule_name: The name of the rule.
        :param pulumi.Input[builtins.str] rule_type: The type of the rule. Valid values:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AutoGroupingRuleState.__new__(_AutoGroupingRuleState)

        __props__.__dict__["exclude_region_ids_scope"] = exclude_region_ids_scope
        __props__.__dict__["exclude_resource_group_ids_scope"] = exclude_resource_group_ids_scope
        __props__.__dict__["exclude_resource_ids_scope"] = exclude_resource_ids_scope
        __props__.__dict__["exclude_resource_types_scope"] = exclude_resource_types_scope
        __props__.__dict__["region_ids_scope"] = region_ids_scope
        __props__.__dict__["resource_group_ids_scope"] = resource_group_ids_scope
        __props__.__dict__["resource_ids_scope"] = resource_ids_scope
        __props__.__dict__["resource_types_scope"] = resource_types_scope
        __props__.__dict__["rule_contents"] = rule_contents
        __props__.__dict__["rule_desc"] = rule_desc
        __props__.__dict__["rule_name"] = rule_name
        __props__.__dict__["rule_type"] = rule_type
        return AutoGroupingRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="excludeRegionIdsScope")
    def exclude_region_ids_scope(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The IDs of regions to be excluded. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "exclude_region_ids_scope")

    @property
    @pulumi.getter(name="excludeResourceGroupIdsScope")
    def exclude_resource_group_ids_scope(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The IDs of resource groups to be excluded. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "exclude_resource_group_ids_scope")

    @property
    @pulumi.getter(name="excludeResourceIdsScope")
    def exclude_resource_ids_scope(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The IDs of resources to be excluded. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "exclude_resource_ids_scope")

    @property
    @pulumi.getter(name="excludeResourceTypesScope")
    def exclude_resource_types_scope(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The resource types to be excluded. Separate multiple resource types with commas (,).
        """
        return pulumi.get(self, "exclude_resource_types_scope")

    @property
    @pulumi.getter(name="regionIdsScope")
    def region_ids_scope(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The IDs of regions. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "region_ids_scope")

    @property
    @pulumi.getter(name="resourceGroupIdsScope")
    def resource_group_ids_scope(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The IDs of resource groups. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "resource_group_ids_scope")

    @property
    @pulumi.getter(name="resourceIdsScope")
    def resource_ids_scope(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The IDs of resources. Separate multiple IDs with commas (,).
        """
        return pulumi.get(self, "resource_ids_scope")

    @property
    @pulumi.getter(name="resourceTypesScope")
    def resource_types_scope(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The resource types. Separate multiple resource types with commas (,).
        """
        return pulumi.get(self, "resource_types_scope")

    @property
    @pulumi.getter(name="ruleContents")
    def rule_contents(self) -> pulumi.Output[Sequence['outputs.AutoGroupingRuleRuleContent']]:
        """
        The content records of the rule. See `rule_contents` below.
        """
        return pulumi.get(self, "rule_contents")

    @property
    @pulumi.getter(name="ruleDesc")
    def rule_desc(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The description of the rule.
        """
        return pulumi.get(self, "rule_desc")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the rule.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="ruleType")
    def rule_type(self) -> pulumi.Output[builtins.str]:
        """
        The type of the rule. Valid values:
        """
        return pulumi.get(self, "rule_type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetIpamIpamsResult',
    'AwaitableGetIpamIpamsResult',
    'get_ipam_ipams',
    'get_ipam_ipams_output',
]

@pulumi.output_type
class GetIpamIpamsResult:
    """
    A collection of values returned by getIpamIpams.
    """
    def __init__(__self__, id=None, ids=None, ipam_id=None, ipam_name=None, ipams=None, name_regex=None, names=None, output_file=None, resource_group_id=None, tags=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if ipam_id and not isinstance(ipam_id, str):
            raise TypeError("Expected argument 'ipam_id' to be a str")
        pulumi.set(__self__, "ipam_id", ipam_id)
        if ipam_name and not isinstance(ipam_name, str):
            raise TypeError("Expected argument 'ipam_name' to be a str")
        pulumi.set(__self__, "ipam_name", ipam_name)
        if ipams and not isinstance(ipams, list):
            raise TypeError("Expected argument 'ipams' to be a list")
        pulumi.set(__self__, "ipams", ipams)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of Ipam IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="ipamId")
    def ipam_id(self) -> Optional[builtins.str]:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "ipam_id")

    @property
    @pulumi.getter(name="ipamName")
    def ipam_name(self) -> Optional[builtins.str]:
        """
        The name of the resource.
        """
        return pulumi.get(self, "ipam_name")

    @property
    @pulumi.getter
    def ipams(self) -> Sequence['outputs.GetIpamIpamsIpamResult']:
        """
        A list of Ipam Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "ipams")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        """
        A list of name of Ipams.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[builtins.str]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, builtins.str]]:
        """
        The tag of the resource.
        """
        return pulumi.get(self, "tags")


class AwaitableGetIpamIpamsResult(GetIpamIpamsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIpamIpamsResult(
            id=self.id,
            ids=self.ids,
            ipam_id=self.ipam_id,
            ipam_name=self.ipam_name,
            ipams=self.ipams,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            resource_group_id=self.resource_group_id,
            tags=self.tags)


def get_ipam_ipams(ids: Optional[Sequence[builtins.str]] = None,
                   ipam_id: Optional[builtins.str] = None,
                   ipam_name: Optional[builtins.str] = None,
                   name_regex: Optional[builtins.str] = None,
                   output_file: Optional[builtins.str] = None,
                   resource_group_id: Optional[builtins.str] = None,
                   tags: Optional[Mapping[str, builtins.str]] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIpamIpamsResult:
    """
    This data source provides Vpc Ipam Ipam available to the user.[What is Ipam](https://next.api.alibabacloud.com/document/VpcIpam/2023-02-28/CreateIpam)

    > **NOTE:** Available since v1.241.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    default = alicloud.resourcemanager.get_resource_groups()
    default_ipam_ipam = alicloud.vpc.IpamIpam("default",
        ipam_description="This is my first Ipam.",
        ipam_name=name,
        operating_region_lists=["cn-hangzhou"])
    default_get_ipam_ipams = pulumi.Output.all(
        id=default_ipam_ipam.id,
        ipam_name=default_ipam_ipam.ipam_name
    ).apply(lambda resolved_outputs: alicloud.vpc.get_ipam_ipams_output(ids=[resolved_outputs['id']],
        name_regex=resolved_outputs['ipam_name'],
        ipam_name=name))

    pulumi.export("alicloudVpcIpamIpamExampleId", default_get_ipam_ipams.ipams[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of Ipam IDs.
    :param builtins.str ipam_id: The first ID of the resource.
    :param builtins.str ipam_name: The name of the resource.
    :param builtins.str name_regex: A regex string to filter results by Group Metric Rule name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str resource_group_id: The ID of the resource group.
    :param Mapping[str, builtins.str] tags: The tag of the resource.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['ipamId'] = ipam_id
    __args__['ipamName'] = ipam_name
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:vpc/getIpamIpams:getIpamIpams', __args__, opts=opts, typ=GetIpamIpamsResult).value

    return AwaitableGetIpamIpamsResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        ipam_id=pulumi.get(__ret__, 'ipam_id'),
        ipam_name=pulumi.get(__ret__, 'ipam_name'),
        ipams=pulumi.get(__ret__, 'ipams'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        resource_group_id=pulumi.get(__ret__, 'resource_group_id'),
        tags=pulumi.get(__ret__, 'tags'))
def get_ipam_ipams_output(ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                          ipam_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                          ipam_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                          name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                          output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                          resource_group_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                          tags: Optional[pulumi.Input[Optional[Mapping[str, builtins.str]]]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIpamIpamsResult]:
    """
    This data source provides Vpc Ipam Ipam available to the user.[What is Ipam](https://next.api.alibabacloud.com/document/VpcIpam/2023-02-28/CreateIpam)

    > **NOTE:** Available since v1.241.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    default = alicloud.resourcemanager.get_resource_groups()
    default_ipam_ipam = alicloud.vpc.IpamIpam("default",
        ipam_description="This is my first Ipam.",
        ipam_name=name,
        operating_region_lists=["cn-hangzhou"])
    default_get_ipam_ipams = pulumi.Output.all(
        id=default_ipam_ipam.id,
        ipam_name=default_ipam_ipam.ipam_name
    ).apply(lambda resolved_outputs: alicloud.vpc.get_ipam_ipams_output(ids=[resolved_outputs['id']],
        name_regex=resolved_outputs['ipam_name'],
        ipam_name=name))

    pulumi.export("alicloudVpcIpamIpamExampleId", default_get_ipam_ipams.ipams[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of Ipam IDs.
    :param builtins.str ipam_id: The first ID of the resource.
    :param builtins.str ipam_name: The name of the resource.
    :param builtins.str name_regex: A regex string to filter results by Group Metric Rule name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str resource_group_id: The ID of the resource group.
    :param Mapping[str, builtins.str] tags: The tag of the resource.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['ipamId'] = ipam_id
    __args__['ipamName'] = ipam_name
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['tags'] = tags
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:vpc/getIpamIpams:getIpamIpams', __args__, opts=opts, typ=GetIpamIpamsResult)
    return __ret__.apply(lambda __response__: GetIpamIpamsResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        ipam_id=pulumi.get(__response__, 'ipam_id'),
        ipam_name=pulumi.get(__response__, 'ipam_name'),
        ipams=pulumi.get(__response__, 'ipams'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        resource_group_id=pulumi.get(__response__, 'resource_group_id'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'LakeAccountAccountPrivilege',
    'LakeAccountAccountPrivilegePrivilegeObject',
    'GetClustersClusterResult',
    'GetClustersClusterAvailableKernelVersionResult',
    'GetDBClusterLakeVersionsVersionResult',
    'GetDBClustersClusterResult',
    'GetDBClustersClusterAvailableKernelVersionResult',
    'GetResourceGroupsGroupResult',
    'GetZonesZoneResult',
]

@pulumi.output_type
class LakeAccountAccountPrivilege(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "privilegeObject":
            suggest = "privilege_object"
        elif key == "privilegeType":
            suggest = "privilege_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in LakeAccountAccountPrivilege. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        LakeAccountAccountPrivilege.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        LakeAccountAccountPrivilege.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 privilege_object: Optional['outputs.LakeAccountAccountPrivilegePrivilegeObject'] = None,
                 privilege_type: Optional[builtins.str] = None,
                 privileges: Optional[Sequence[builtins.str]] = None):
        """
        :param 'LakeAccountAccountPrivilegePrivilegeObjectArgs' privilege_object: Object associated to privileges. See `privilege_object` below.
        :param builtins.str privilege_type: The type of privileges.
        :param Sequence[builtins.str] privileges: privilege list.
        """
        if privilege_object is not None:
            pulumi.set(__self__, "privilege_object", privilege_object)
        if privilege_type is not None:
            pulumi.set(__self__, "privilege_type", privilege_type)
        if privileges is not None:
            pulumi.set(__self__, "privileges", privileges)

    @property
    @pulumi.getter(name="privilegeObject")
    def privilege_object(self) -> Optional['outputs.LakeAccountAccountPrivilegePrivilegeObject']:
        """
        Object associated to privileges. See `privilege_object` below.
        """
        return pulumi.get(self, "privilege_object")

    @property
    @pulumi.getter(name="privilegeType")
    def privilege_type(self) -> Optional[builtins.str]:
        """
        The type of privileges.
        """
        return pulumi.get(self, "privilege_type")

    @property
    @pulumi.getter
    def privileges(self) -> Optional[Sequence[builtins.str]]:
        """
        privilege list.
        """
        return pulumi.get(self, "privileges")


@pulumi.output_type
class LakeAccountAccountPrivilegePrivilegeObject(dict):
    def __init__(__self__, *,
                 column: Optional[builtins.str] = None,
                 database: Optional[builtins.str] = None,
                 table: Optional[builtins.str] = None):
        """
        :param builtins.str column: The name of column.
        :param builtins.str database: The name of database.
        :param builtins.str table: The name of table.
        """
        if column is not None:
            pulumi.set(__self__, "column", column)
        if database is not None:
            pulumi.set(__self__, "database", database)
        if table is not None:
            pulumi.set(__self__, "table", table)

    @property
    @pulumi.getter
    def column(self) -> Optional[builtins.str]:
        """
        The name of column.
        """
        return pulumi.get(self, "column")

    @property
    @pulumi.getter
    def database(self) -> Optional[builtins.str]:
        """
        The name of database.
        """
        return pulumi.get(self, "database")

    @property
    @pulumi.getter
    def table(self) -> Optional[builtins.str]:
        """
        The name of table.
        """
        return pulumi.get(self, "table")


@pulumi.output_type
class GetClustersClusterResult(dict):
    def __init__(__self__, *,
                 auto_renew_period: builtins.int,
                 available_kernel_versions: Sequence['outputs.GetClustersClusterAvailableKernelVersionResult'],
                 charge_type: builtins.str,
                 commodity_code: builtins.str,
                 compute_resource: builtins.str,
                 connection_string: builtins.str,
                 create_time: builtins.str,
                 db_cluster_category: builtins.str,
                 db_cluster_id: builtins.str,
                 db_cluster_network_type: builtins.str,
                 db_cluster_type: builtins.str,
                 db_cluster_version: builtins.str,
                 db_node_class: builtins.str,
                 db_node_count: builtins.int,
                 db_node_storage: builtins.int,
                 description: builtins.str,
                 disk_type: builtins.str,
                 dts_job_id: builtins.str,
                 elastic_io_resource: builtins.int,
                 engine: builtins.str,
                 engine_version: builtins.str,
                 executor_count: builtins.str,
                 expire_time: builtins.str,
                 expired: builtins.str,
                 id: builtins.str,
                 kernel_version: builtins.str,
                 lock_mode: builtins.str,
                 lock_reason: builtins.str,
                 maintain_time: builtins.str,
                 mode: builtins.str,
                 network_type: builtins.str,
                 payment_type: builtins.str,
                 port: builtins.int,
                 rds_instance_id: builtins.str,
                 region_id: builtins.str,
                 renewal_status: builtins.str,
                 resource_group_id: builtins.str,
                 security_ips: Sequence[builtins.str],
                 status: builtins.str,
                 storage_resource: builtins.str,
                 tags: Mapping[str, builtins.str],
                 vpc_cloud_instance_id: builtins.str,
                 vpc_id: builtins.str,
                 vswitch_id: builtins.str,
                 zone_id: builtins.str):
        """
        :param builtins.str charge_type: Billing method. Value options: `PostPaid` for Pay-As-You-Go and `PrePaid` for subscription.
        :param builtins.str create_time: The CreateTime of the ADB cluster.
        :param builtins.str db_node_class: The DBNodeClass of the ADB cluster.
        :param builtins.int db_node_count: The DBNodeCount of the ADB cluster.
        :param builtins.int db_node_storage: The DBNodeStorage of the ADB cluster.
        :param builtins.str description: The description of the ADB cluster.
        :param builtins.str expire_time: Expiration time. Pay-As-You-Go clusters never expire.
        :param builtins.str expired: The expired of the ADB cluster.
        :param builtins.str id: The ID of the ADB cluster.
        :param builtins.str lock_mode: The LockMode of the ADB cluster.
        :param builtins.str network_type: The DBClusterNetworkType of the ADB cluster.
        :param builtins.str region_id: Region ID the cluster belongs to.
        :param builtins.str status: The status of the cluster. Valid values: `Preparing`, `Creating`, `Restoring`, `Running`, `Deleting`, `ClassChanging`, `NetAddressCreating`, `NetAddressDeleting`. For more information, see [Cluster status](https://www.alibabacloud.com/help/doc-detail/143075.htm).
        :param Mapping[str, builtins.str] tags: A mapping of tags to assign to the resource.
               - Key: It can be up to 64 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It cannot be a null string.
               - Value: It can be up to 128 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It can be a null string.
        :param builtins.str vpc_id: ID of the VPC the cluster belongs to.
        :param builtins.str zone_id: The ZoneId of the ADB cluster.
        """
        pulumi.set(__self__, "auto_renew_period", auto_renew_period)
        pulumi.set(__self__, "available_kernel_versions", available_kernel_versions)
        pulumi.set(__self__, "charge_type", charge_type)
        pulumi.set(__self__, "commodity_code", commodity_code)
        pulumi.set(__self__, "compute_resource", compute_resource)
        pulumi.set(__self__, "connection_string", connection_string)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "db_cluster_category", db_cluster_category)
        pulumi.set(__self__, "db_cluster_id", db_cluster_id)
        pulumi.set(__self__, "db_cluster_network_type", db_cluster_network_type)
        pulumi.set(__self__, "db_cluster_type", db_cluster_type)
        pulumi.set(__self__, "db_cluster_version", db_cluster_version)
        pulumi.set(__self__, "db_node_class", db_node_class)
        pulumi.set(__self__, "db_node_count", db_node_count)
        pulumi.set(__self__, "db_node_storage", db_node_storage)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "disk_type", disk_type)
        pulumi.set(__self__, "dts_job_id", dts_job_id)
        pulumi.set(__self__, "elastic_io_resource", elastic_io_resource)
        pulumi.set(__self__, "engine", engine)
        pulumi.set(__self__, "engine_version", engine_version)
        pulumi.set(__self__, "executor_count", executor_count)
        pulumi.set(__self__, "expire_time", expire_time)
        pulumi.set(__self__, "expired", expired)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "kernel_version", kernel_version)
        pulumi.set(__self__, "lock_mode", lock_mode)
        pulumi.set(__self__, "lock_reason", lock_reason)
        pulumi.set(__self__, "maintain_time", maintain_time)
        pulumi.set(__self__, "mode", mode)
        pulumi.set(__self__, "network_type", network_type)
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "rds_instance_id", rds_instance_id)
        pulumi.set(__self__, "region_id", region_id)
        pulumi.set(__self__, "renewal_status", renewal_status)
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        pulumi.set(__self__, "security_ips", security_ips)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "storage_resource", storage_resource)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "vpc_cloud_instance_id", vpc_cloud_instance_id)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "vswitch_id", vswitch_id)
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="autoRenewPeriod")
    def auto_renew_period(self) -> builtins.int:
        return pulumi.get(self, "auto_renew_period")

    @property
    @pulumi.getter(name="availableKernelVersions")
    def available_kernel_versions(self) -> Sequence['outputs.GetClustersClusterAvailableKernelVersionResult']:
        return pulumi.get(self, "available_kernel_versions")

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> builtins.str:
        """
        Billing method. Value options: `PostPaid` for Pay-As-You-Go and `PrePaid` for subscription.
        """
        return pulumi.get(self, "charge_type")

    @property
    @pulumi.getter(name="commodityCode")
    def commodity_code(self) -> builtins.str:
        return pulumi.get(self, "commodity_code")

    @property
    @pulumi.getter(name="computeResource")
    def compute_resource(self) -> builtins.str:
        return pulumi.get(self, "compute_resource")

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> builtins.str:
        return pulumi.get(self, "connection_string")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        The CreateTime of the ADB cluster.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dbClusterCategory")
    def db_cluster_category(self) -> builtins.str:
        return pulumi.get(self, "db_cluster_category")

    @property
    @pulumi.getter(name="dbClusterId")
    def db_cluster_id(self) -> builtins.str:
        return pulumi.get(self, "db_cluster_id")

    @property
    @pulumi.getter(name="dbClusterNetworkType")
    def db_cluster_network_type(self) -> builtins.str:
        return pulumi.get(self, "db_cluster_network_type")

    @property
    @pulumi.getter(name="dbClusterType")
    def db_cluster_type(self) -> builtins.str:
        return pulumi.get(self, "db_cluster_type")

    @property
    @pulumi.getter(name="dbClusterVersion")
    def db_cluster_version(self) -> builtins.str:
        return pulumi.get(self, "db_cluster_version")

    @property
    @pulumi.getter(name="dbNodeClass")
    def db_node_class(self) -> builtins.str:
        """
        The DBNodeClass of the ADB cluster.
        """
        return pulumi.get(self, "db_node_class")

    @property
    @pulumi.getter(name="dbNodeCount")
    def db_node_count(self) -> builtins.int:
        """
        The DBNodeCount of the ADB cluster.
        """
        return pulumi.get(self, "db_node_count")

    @property
    @pulumi.getter(name="dbNodeStorage")
    def db_node_storage(self) -> builtins.int:
        """
        The DBNodeStorage of the ADB cluster.
        """
        return pulumi.get(self, "db_node_storage")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        The description of the ADB cluster.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> builtins.str:
        return pulumi.get(self, "disk_type")

    @property
    @pulumi.getter(name="dtsJobId")
    def dts_job_id(self) -> builtins.str:
        return pulumi.get(self, "dts_job_id")

    @property
    @pulumi.getter(name="elasticIoResource")
    def elastic_io_resource(self) -> builtins.int:
        return pulumi.get(self, "elastic_io_resource")

    @property
    @pulumi.getter
    def engine(self) -> builtins.str:
        return pulumi.get(self, "engine")

    @property
    @pulumi.getter(name="engineVersion")
    def engine_version(self) -> builtins.str:
        return pulumi.get(self, "engine_version")

    @property
    @pulumi.getter(name="executorCount")
    def executor_count(self) -> builtins.str:
        return pulumi.get(self, "executor_count")

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> builtins.str:
        """
        Expiration time. Pay-As-You-Go clusters never expire.
        """
        return pulumi.get(self, "expire_time")

    @property
    @pulumi.getter
    def expired(self) -> builtins.str:
        """
        The expired of the ADB cluster.
        """
        return pulumi.get(self, "expired")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the ADB cluster.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="kernelVersion")
    def kernel_version(self) -> builtins.str:
        return pulumi.get(self, "kernel_version")

    @property
    @pulumi.getter(name="lockMode")
    def lock_mode(self) -> builtins.str:
        """
        The LockMode of the ADB cluster.
        """
        return pulumi.get(self, "lock_mode")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> builtins.str:
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="maintainTime")
    def maintain_time(self) -> builtins.str:
        return pulumi.get(self, "maintain_time")

    @property
    @pulumi.getter
    def mode(self) -> builtins.str:
        return pulumi.get(self, "mode")

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> builtins.str:
        """
        The DBClusterNetworkType of the ADB cluster.
        """
        return pulumi.get(self, "network_type")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> builtins.str:
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter
    def port(self) -> builtins.int:
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="rdsInstanceId")
    def rds_instance_id(self) -> builtins.str:
        return pulumi.get(self, "rds_instance_id")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> builtins.str:
        """
        Region ID the cluster belongs to.
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> builtins.str:
        return pulumi.get(self, "renewal_status")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> builtins.str:
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="securityIps")
    def security_ips(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "security_ips")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        The status of the cluster. Valid values: `Preparing`, `Creating`, `Restoring`, `Running`, `Deleting`, `ClassChanging`, `NetAddressCreating`, `NetAddressDeleting`. For more information, see [Cluster status](https://www.alibabacloud.com/help/doc-detail/143075.htm).
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="storageResource")
    def storage_resource(self) -> builtins.str:
        return pulumi.get(self, "storage_resource")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, builtins.str]:
        """
        A mapping of tags to assign to the resource.
        - Key: It can be up to 64 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It cannot be a null string.
        - Value: It can be up to 128 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It can be a null string.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="vpcCloudInstanceId")
    def vpc_cloud_instance_id(self) -> builtins.str:
        return pulumi.get(self, "vpc_cloud_instance_id")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        ID of the VPC the cluster belongs to.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> builtins.str:
        return pulumi.get(self, "vswitch_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> builtins.str:
        """
        The ZoneId of the ADB cluster.
        """
        return pulumi.get(self, "zone_id")


@pulumi.output_type
class GetClustersClusterAvailableKernelVersionResult(dict):
    def __init__(__self__, *,
                 expire_date: builtins.str,
                 kernel_version: builtins.str,
                 release_date: builtins.str):
        pulumi.set(__self__, "expire_date", expire_date)
        pulumi.set(__self__, "kernel_version", kernel_version)
        pulumi.set(__self__, "release_date", release_date)

    @property
    @pulumi.getter(name="expireDate")
    def expire_date(self) -> builtins.str:
        return pulumi.get(self, "expire_date")

    @property
    @pulumi.getter(name="kernelVersion")
    def kernel_version(self) -> builtins.str:
        return pulumi.get(self, "kernel_version")

    @property
    @pulumi.getter(name="releaseDate")
    def release_date(self) -> builtins.str:
        return pulumi.get(self, "release_date")


@pulumi.output_type
class GetDBClusterLakeVersionsVersionResult(dict):
    def __init__(__self__, *,
                 commodity_code: builtins.str,
                 compute_resource: builtins.str,
                 connection_string: builtins.str,
                 create_time: builtins.str,
                 db_cluster_id: builtins.str,
                 db_cluster_version: builtins.str,
                 engine: builtins.str,
                 engine_version: builtins.str,
                 expire_time: builtins.str,
                 expired: builtins.str,
                 id: builtins.str,
                 lock_mode: builtins.str,
                 lock_reason: builtins.str,
                 payment_type: builtins.str,
                 port: builtins.str,
                 resource_group_id: builtins.str,
                 status: builtins.str,
                 storage_resource: builtins.str,
                 vpc_id: builtins.str,
                 vswitch_id: builtins.str,
                 zone_id: builtins.str):
        """
        :param builtins.str commodity_code: The name of the service.
        :param builtins.str compute_resource: The specifications of computing resources in elastic mode. The increase of resources can speed up queries.
        :param builtins.str connection_string: The endpoint of the cluster.
        :param builtins.str create_time: The CreateTime of the ADB cluster.
        :param builtins.str db_cluster_id: The ID of the DBCluster.
        :param builtins.str db_cluster_version: The db cluster version.
        :param builtins.str engine: The engine of the database.
        :param builtins.str engine_version: The engine version of the database.
        :param builtins.str expire_time: The time when the cluster expires.
        :param builtins.str expired: Indicates whether the cluster has expired.
        :param builtins.str id: The ID of the DBCluster.
        :param builtins.str lock_mode: The lock mode of the cluster.
        :param builtins.str lock_reason: The reason why the cluster is locked.
        :param builtins.str payment_type: The payment type of the resource.
        :param builtins.str port: The port that is used to access the cluster.
        :param builtins.str resource_group_id: The ID of the resource group.
        :param builtins.str status: The status of the resource. Valid values: `Preparing`, `Creating`, `Restoring`, `Running`, `Deleting`, `ClassChanging`, `NetAddressCreating`, `NetAddressDeleting`.
        :param builtins.str storage_resource: The specifications of storage resources in elastic mode. The resources are used for data read and write operations.
        :param builtins.str vpc_id: The vpc id.
        :param builtins.str vswitch_id: The vswitch id.
        :param builtins.str zone_id: The zone ID  of the resource.
        """
        pulumi.set(__self__, "commodity_code", commodity_code)
        pulumi.set(__self__, "compute_resource", compute_resource)
        pulumi.set(__self__, "connection_string", connection_string)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "db_cluster_id", db_cluster_id)
        pulumi.set(__self__, "db_cluster_version", db_cluster_version)
        pulumi.set(__self__, "engine", engine)
        pulumi.set(__self__, "engine_version", engine_version)
        pulumi.set(__self__, "expire_time", expire_time)
        pulumi.set(__self__, "expired", expired)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "lock_mode", lock_mode)
        pulumi.set(__self__, "lock_reason", lock_reason)
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "storage_resource", storage_resource)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "vswitch_id", vswitch_id)
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="commodityCode")
    def commodity_code(self) -> builtins.str:
        """
        The name of the service.
        """
        return pulumi.get(self, "commodity_code")

    @property
    @pulumi.getter(name="computeResource")
    def compute_resource(self) -> builtins.str:
        """
        The specifications of computing resources in elastic mode. The increase of resources can speed up queries.
        """
        return pulumi.get(self, "compute_resource")

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> builtins.str:
        """
        The endpoint of the cluster.
        """
        return pulumi.get(self, "connection_string")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        The CreateTime of the ADB cluster.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dbClusterId")
    def db_cluster_id(self) -> builtins.str:
        """
        The ID of the DBCluster.
        """
        return pulumi.get(self, "db_cluster_id")

    @property
    @pulumi.getter(name="dbClusterVersion")
    def db_cluster_version(self) -> builtins.str:
        """
        The db cluster version.
        """
        return pulumi.get(self, "db_cluster_version")

    @property
    @pulumi.getter
    def engine(self) -> builtins.str:
        """
        The engine of the database.
        """
        return pulumi.get(self, "engine")

    @property
    @pulumi.getter(name="engineVersion")
    def engine_version(self) -> builtins.str:
        """
        The engine version of the database.
        """
        return pulumi.get(self, "engine_version")

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> builtins.str:
        """
        The time when the cluster expires.
        """
        return pulumi.get(self, "expire_time")

    @property
    @pulumi.getter
    def expired(self) -> builtins.str:
        """
        Indicates whether the cluster has expired.
        """
        return pulumi.get(self, "expired")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the DBCluster.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lockMode")
    def lock_mode(self) -> builtins.str:
        """
        The lock mode of the cluster.
        """
        return pulumi.get(self, "lock_mode")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> builtins.str:
        """
        The reason why the cluster is locked.
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> builtins.str:
        """
        The payment type of the resource.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter
    def port(self) -> builtins.str:
        """
        The port that is used to access the cluster.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> builtins.str:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        The status of the resource. Valid values: `Preparing`, `Creating`, `Restoring`, `Running`, `Deleting`, `ClassChanging`, `NetAddressCreating`, `NetAddressDeleting`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="storageResource")
    def storage_resource(self) -> builtins.str:
        """
        The specifications of storage resources in elastic mode. The resources are used for data read and write operations.
        """
        return pulumi.get(self, "storage_resource")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        The vpc id.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> builtins.str:
        """
        The vswitch id.
        """
        return pulumi.get(self, "vswitch_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> builtins.str:
        """
        The zone ID  of the resource.
        """
        return pulumi.get(self, "zone_id")


@pulumi.output_type
class GetDBClustersClusterResult(dict):
    def __init__(__self__, *,
                 auto_renew_period: builtins.int,
                 available_kernel_versions: Sequence['outputs.GetDBClustersClusterAvailableKernelVersionResult'],
                 charge_type: builtins.str,
                 commodity_code: builtins.str,
                 compute_resource: builtins.str,
                 connection_string: builtins.str,
                 create_time: builtins.str,
                 db_cluster_category: builtins.str,
                 db_cluster_id: builtins.str,
                 db_cluster_network_type: builtins.str,
                 db_cluster_type: builtins.str,
                 db_cluster_version: builtins.str,
                 db_node_class: builtins.str,
                 db_node_count: builtins.int,
                 db_node_storage: builtins.int,
                 description: builtins.str,
                 disk_type: builtins.str,
                 dts_job_id: builtins.str,
                 elastic_io_resource: builtins.int,
                 engine: builtins.str,
                 engine_version: builtins.str,
                 executor_count: builtins.str,
                 expire_time: builtins.str,
                 expired: builtins.str,
                 id: builtins.str,
                 kernel_version: builtins.str,
                 lock_mode: builtins.str,
                 lock_reason: builtins.str,
                 maintain_time: builtins.str,
                 mode: builtins.str,
                 network_type: builtins.str,
                 payment_type: builtins.str,
                 port: builtins.int,
                 rds_instance_id: builtins.str,
                 region_id: builtins.str,
                 renewal_status: builtins.str,
                 resource_group_id: builtins.str,
                 security_ips: Sequence[builtins.str],
                 status: builtins.str,
                 storage_resource: builtins.str,
                 tags: Mapping[str, builtins.str],
                 vpc_cloud_instance_id: builtins.str,
                 vpc_id: builtins.str,
                 vswitch_id: builtins.str,
                 zone_id: builtins.str):
        """
        :param builtins.int auto_renew_period: Auto-renewal period of an cluster, in the unit of the month.
        :param Sequence['GetDBClustersClusterAvailableKernelVersionArgs'] available_kernel_versions: The minor versions to which you can update the current minor version of the cluster.
        :param builtins.str charge_type: The payment type of the resource.
        :param builtins.str commodity_code: The name of the service.
        :param builtins.str compute_resource: The specifications of computing resources in elastic mode. The increase of resources can speed up queries. AnalyticDB for MySQL automatically scales computing resources.
        :param builtins.str connection_string: The endpoint of the cluster.
        :param builtins.str create_time: The CreateTime of the ADB cluster.
        :param builtins.str db_cluster_category: The db cluster category.
        :param builtins.str db_cluster_id: The db cluster id.
        :param builtins.str db_cluster_network_type: The db cluster network type.
        :param builtins.str db_cluster_type: The db cluster type.
        :param builtins.str db_cluster_version: The db cluster version.
        :param builtins.str db_node_class: The db node class.
        :param builtins.int db_node_count: The db node count.
        :param builtins.int db_node_storage: The db node storage.
        :param builtins.str description: The description of DBCluster.
        :param builtins.str disk_type: The type of the disk.
        :param builtins.str dts_job_id: The ID of the data synchronization task in Data Transmission Service (DTS). This parameter is valid only for analytic instances.
        :param builtins.int elastic_io_resource: The elastic io resource.
        :param builtins.str engine: The engine of the database.
        :param builtins.str engine_version: The engine version of the database.
        :param builtins.str executor_count: The number of nodes. The node resources are used for data computing in elastic mode.
        :param builtins.str expire_time: The time when the cluster expires.
        :param builtins.str expired: Indicates whether the cluster has expired.
        :param builtins.str id: The ID of the DBCluster.
        :param builtins.str kernel_version: The minor version. Example: 3.1.9.
        :param builtins.str lock_mode: The lock mode of the cluster.
        :param builtins.str lock_reason: The reason why the cluster is locked.
        :param builtins.str maintain_time: The maintenance window of the cluster.
        :param builtins.str mode: The lock mode of the cluster.
        :param builtins.str network_type: The db cluster network type.
        :param builtins.str payment_type: The payment type of the resource.
        :param builtins.int port: The port that is used to access the cluster.
        :param builtins.str rds_instance_id: The ID of the ApsaraDB RDS instance from which data is synchronized to the cluster. This parameter is valid only for analytic instances.
        :param builtins.str region_id: The region ID  of the resource.
        :param builtins.str renewal_status: The status of renewal.
        :param builtins.str resource_group_id: The ID of the resource group.
        :param Sequence[builtins.str] security_ips: List of IP addresses allowed to access all databases of an cluster.
        :param builtins.str status: The status of the resource.
        :param builtins.str storage_resource: The specifications of storage resources in elastic mode. The resources are used for data read and write operations. The increase of resources can improve the read and write performance of your cluster.
        :param Mapping[str, builtins.str] tags: A map of tags assigned to the cluster.
        :param builtins.str vpc_cloud_instance_id: The vpc cloud instance id.
        :param builtins.str vpc_id: The vpc id.
        :param builtins.str vswitch_id: The vswitch id.
        :param builtins.str zone_id: The zone ID  of the resource.
        """
        pulumi.set(__self__, "auto_renew_period", auto_renew_period)
        pulumi.set(__self__, "available_kernel_versions", available_kernel_versions)
        pulumi.set(__self__, "charge_type", charge_type)
        pulumi.set(__self__, "commodity_code", commodity_code)
        pulumi.set(__self__, "compute_resource", compute_resource)
        pulumi.set(__self__, "connection_string", connection_string)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "db_cluster_category", db_cluster_category)
        pulumi.set(__self__, "db_cluster_id", db_cluster_id)
        pulumi.set(__self__, "db_cluster_network_type", db_cluster_network_type)
        pulumi.set(__self__, "db_cluster_type", db_cluster_type)
        pulumi.set(__self__, "db_cluster_version", db_cluster_version)
        pulumi.set(__self__, "db_node_class", db_node_class)
        pulumi.set(__self__, "db_node_count", db_node_count)
        pulumi.set(__self__, "db_node_storage", db_node_storage)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "disk_type", disk_type)
        pulumi.set(__self__, "dts_job_id", dts_job_id)
        pulumi.set(__self__, "elastic_io_resource", elastic_io_resource)
        pulumi.set(__self__, "engine", engine)
        pulumi.set(__self__, "engine_version", engine_version)
        pulumi.set(__self__, "executor_count", executor_count)
        pulumi.set(__self__, "expire_time", expire_time)
        pulumi.set(__self__, "expired", expired)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "kernel_version", kernel_version)
        pulumi.set(__self__, "lock_mode", lock_mode)
        pulumi.set(__self__, "lock_reason", lock_reason)
        pulumi.set(__self__, "maintain_time", maintain_time)
        pulumi.set(__self__, "mode", mode)
        pulumi.set(__self__, "network_type", network_type)
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "rds_instance_id", rds_instance_id)
        pulumi.set(__self__, "region_id", region_id)
        pulumi.set(__self__, "renewal_status", renewal_status)
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        pulumi.set(__self__, "security_ips", security_ips)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "storage_resource", storage_resource)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "vpc_cloud_instance_id", vpc_cloud_instance_id)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "vswitch_id", vswitch_id)
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="autoRenewPeriod")
    def auto_renew_period(self) -> builtins.int:
        """
        Auto-renewal period of an cluster, in the unit of the month.
        """
        return pulumi.get(self, "auto_renew_period")

    @property
    @pulumi.getter(name="availableKernelVersions")
    def available_kernel_versions(self) -> Sequence['outputs.GetDBClustersClusterAvailableKernelVersionResult']:
        """
        The minor versions to which you can update the current minor version of the cluster.
        """
        return pulumi.get(self, "available_kernel_versions")

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> builtins.str:
        """
        The payment type of the resource.
        """
        return pulumi.get(self, "charge_type")

    @property
    @pulumi.getter(name="commodityCode")
    def commodity_code(self) -> builtins.str:
        """
        The name of the service.
        """
        return pulumi.get(self, "commodity_code")

    @property
    @pulumi.getter(name="computeResource")
    def compute_resource(self) -> builtins.str:
        """
        The specifications of computing resources in elastic mode. The increase of resources can speed up queries. AnalyticDB for MySQL automatically scales computing resources.
        """
        return pulumi.get(self, "compute_resource")

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> builtins.str:
        """
        The endpoint of the cluster.
        """
        return pulumi.get(self, "connection_string")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        The CreateTime of the ADB cluster.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dbClusterCategory")
    def db_cluster_category(self) -> builtins.str:
        """
        The db cluster category.
        """
        return pulumi.get(self, "db_cluster_category")

    @property
    @pulumi.getter(name="dbClusterId")
    def db_cluster_id(self) -> builtins.str:
        """
        The db cluster id.
        """
        return pulumi.get(self, "db_cluster_id")

    @property
    @pulumi.getter(name="dbClusterNetworkType")
    def db_cluster_network_type(self) -> builtins.str:
        """
        The db cluster network type.
        """
        return pulumi.get(self, "db_cluster_network_type")

    @property
    @pulumi.getter(name="dbClusterType")
    def db_cluster_type(self) -> builtins.str:
        """
        The db cluster type.
        """
        return pulumi.get(self, "db_cluster_type")

    @property
    @pulumi.getter(name="dbClusterVersion")
    def db_cluster_version(self) -> builtins.str:
        """
        The db cluster version.
        """
        return pulumi.get(self, "db_cluster_version")

    @property
    @pulumi.getter(name="dbNodeClass")
    def db_node_class(self) -> builtins.str:
        """
        The db node class.
        """
        return pulumi.get(self, "db_node_class")

    @property
    @pulumi.getter(name="dbNodeCount")
    def db_node_count(self) -> builtins.int:
        """
        The db node count.
        """
        return pulumi.get(self, "db_node_count")

    @property
    @pulumi.getter(name="dbNodeStorage")
    def db_node_storage(self) -> builtins.int:
        """
        The db node storage.
        """
        return pulumi.get(self, "db_node_storage")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        The description of DBCluster.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> builtins.str:
        """
        The type of the disk.
        """
        return pulumi.get(self, "disk_type")

    @property
    @pulumi.getter(name="dtsJobId")
    def dts_job_id(self) -> builtins.str:
        """
        The ID of the data synchronization task in Data Transmission Service (DTS). This parameter is valid only for analytic instances.
        """
        return pulumi.get(self, "dts_job_id")

    @property
    @pulumi.getter(name="elasticIoResource")
    def elastic_io_resource(self) -> builtins.int:
        """
        The elastic io resource.
        """
        return pulumi.get(self, "elastic_io_resource")

    @property
    @pulumi.getter
    def engine(self) -> builtins.str:
        """
        The engine of the database.
        """
        return pulumi.get(self, "engine")

    @property
    @pulumi.getter(name="engineVersion")
    def engine_version(self) -> builtins.str:
        """
        The engine version of the database.
        """
        return pulumi.get(self, "engine_version")

    @property
    @pulumi.getter(name="executorCount")
    def executor_count(self) -> builtins.str:
        """
        The number of nodes. The node resources are used for data computing in elastic mode.
        """
        return pulumi.get(self, "executor_count")

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> builtins.str:
        """
        The time when the cluster expires.
        """
        return pulumi.get(self, "expire_time")

    @property
    @pulumi.getter
    def expired(self) -> builtins.str:
        """
        Indicates whether the cluster has expired.
        """
        return pulumi.get(self, "expired")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the DBCluster.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="kernelVersion")
    def kernel_version(self) -> builtins.str:
        """
        The minor version. Example: 3.1.9.
        """
        return pulumi.get(self, "kernel_version")

    @property
    @pulumi.getter(name="lockMode")
    def lock_mode(self) -> builtins.str:
        """
        The lock mode of the cluster.
        """
        return pulumi.get(self, "lock_mode")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> builtins.str:
        """
        The reason why the cluster is locked.
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="maintainTime")
    def maintain_time(self) -> builtins.str:
        """
        The maintenance window of the cluster.
        """
        return pulumi.get(self, "maintain_time")

    @property
    @pulumi.getter
    def mode(self) -> builtins.str:
        """
        The lock mode of the cluster.
        """
        return pulumi.get(self, "mode")

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> builtins.str:
        """
        The db cluster network type.
        """
        return pulumi.get(self, "network_type")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> builtins.str:
        """
        The payment type of the resource.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter
    def port(self) -> builtins.int:
        """
        The port that is used to access the cluster.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="rdsInstanceId")
    def rds_instance_id(self) -> builtins.str:
        """
        The ID of the ApsaraDB RDS instance from which data is synchronized to the cluster. This parameter is valid only for analytic instances.
        """
        return pulumi.get(self, "rds_instance_id")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> builtins.str:
        """
        The region ID  of the resource.
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> builtins.str:
        """
        The status of renewal.
        """
        return pulumi.get(self, "renewal_status")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> builtins.str:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="securityIps")
    def security_ips(self) -> Sequence[builtins.str]:
        """
        List of IP addresses allowed to access all databases of an cluster.
        """
        return pulumi.get(self, "security_ips")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="storageResource")
    def storage_resource(self) -> builtins.str:
        """
        The specifications of storage resources in elastic mode. The resources are used for data read and write operations. The increase of resources can improve the read and write performance of your cluster.
        """
        return pulumi.get(self, "storage_resource")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, builtins.str]:
        """
        A map of tags assigned to the cluster.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="vpcCloudInstanceId")
    def vpc_cloud_instance_id(self) -> builtins.str:
        """
        The vpc cloud instance id.
        """
        return pulumi.get(self, "vpc_cloud_instance_id")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        The vpc id.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> builtins.str:
        """
        The vswitch id.
        """
        return pulumi.get(self, "vswitch_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> builtins.str:
        """
        The zone ID  of the resource.
        """
        return pulumi.get(self, "zone_id")


@pulumi.output_type
class GetDBClustersClusterAvailableKernelVersionResult(dict):
    def __init__(__self__, *,
                 expire_date: builtins.str,
                 kernel_version: builtins.str,
                 release_date: builtins.str):
        """
        :param builtins.str expire_date: The maintenance expiration time of the version
        :param builtins.str kernel_version: The minor version. Example: 3.1.9.
        :param builtins.str release_date: The time when the minor version was released.
        """
        pulumi.set(__self__, "expire_date", expire_date)
        pulumi.set(__self__, "kernel_version", kernel_version)
        pulumi.set(__self__, "release_date", release_date)

    @property
    @pulumi.getter(name="expireDate")
    def expire_date(self) -> builtins.str:
        """
        The maintenance expiration time of the version
        """
        return pulumi.get(self, "expire_date")

    @property
    @pulumi.getter(name="kernelVersion")
    def kernel_version(self) -> builtins.str:
        """
        The minor version. Example: 3.1.9.
        """
        return pulumi.get(self, "kernel_version")

    @property
    @pulumi.getter(name="releaseDate")
    def release_date(self) -> builtins.str:
        """
        The time when the minor version was released.
        """
        return pulumi.get(self, "release_date")


@pulumi.output_type
class GetResourceGroupsGroupResult(dict):
    def __init__(__self__, *,
                 create_time: builtins.str,
                 db_cluster_id: builtins.str,
                 group_name: builtins.str,
                 group_type: builtins.str,
                 id: builtins.str,
                 node_num: builtins.int,
                 user: builtins.str):
        """
        :param builtins.str create_time: Creation time.
        :param builtins.str db_cluster_id: DBClusterId
        :param builtins.str group_name: The name of the resource pool, which cannot exceed 64 bytes in length.
        :param builtins.str group_type: Query type, value description:
               * **etl**: Batch query mode.
               * **interactive**: interactive Query mode
               * **default_type**: the default query mode.
        :param builtins.str id: The `key` of the resource supplied above.The value is formulated as `<db_cluster_id>:<group_name>`.
        :param builtins.int node_num: The number of nodes. The default number of nodes is 0. The number of nodes must be less than or equal to the number of nodes whose resource name is USER_DEFAULT.
        :param builtins.str user: Binding User.
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "db_cluster_id", db_cluster_id)
        pulumi.set(__self__, "group_name", group_name)
        pulumi.set(__self__, "group_type", group_type)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "node_num", node_num)
        pulumi.set(__self__, "user", user)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        Creation time.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dbClusterId")
    def db_cluster_id(self) -> builtins.str:
        """
        DBClusterId
        """
        return pulumi.get(self, "db_cluster_id")

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> builtins.str:
        """
        The name of the resource pool, which cannot exceed 64 bytes in length.
        """
        return pulumi.get(self, "group_name")

    @property
    @pulumi.getter(name="groupType")
    def group_type(self) -> builtins.str:
        """
        Query type, value description:
        * **etl**: Batch query mode.
        * **interactive**: interactive Query mode
        * **default_type**: the default query mode.
        """
        return pulumi.get(self, "group_type")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The `key` of the resource supplied above.The value is formulated as `<db_cluster_id>:<group_name>`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="nodeNum")
    def node_num(self) -> builtins.int:
        """
        The number of nodes. The default number of nodes is 0. The number of nodes must be less than or equal to the number of nodes whose resource name is USER_DEFAULT.
        """
        return pulumi.get(self, "node_num")

    @property
    @pulumi.getter
    def user(self) -> builtins.str:
        """
        Binding User.
        """
        return pulumi.get(self, "user")


@pulumi.output_type
class GetZonesZoneResult(dict):
    def __init__(__self__, *,
                 id: builtins.str,
                 multi_zone_ids: Sequence[builtins.str]):
        """
        :param builtins.str id: ID of the zone.
        :param Sequence[builtins.str] multi_zone_ids: A list of zone ids in which the multi zone.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "multi_zone_ids", multi_zone_ids)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        ID of the zone.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="multiZoneIds")
    def multi_zone_ids(self) -> Sequence[builtins.str]:
        """
        A list of zone ids in which the multi zone.
        """
        return pulumi.get(self, "multi_zone_ids")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['LoadBalancerZoneShiftedAttachmentArgs', 'LoadBalancerZoneShiftedAttachment']

@pulumi.input_type
class LoadBalancerZoneShiftedAttachmentArgs:
    def __init__(__self__, *,
                 load_balancer_id: pulumi.Input[builtins.str],
                 vswitch_id: pulumi.Input[builtins.str],
                 zone_id: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a LoadBalancerZoneShiftedAttachment resource.
        :param pulumi.Input[builtins.str] load_balancer_id: Network load balancer id
        :param pulumi.Input[builtins.str] vswitch_id: The list of zones and vSwitch mappings
        :param pulumi.Input[builtins.str] zone_id: ZoneId
        """
        pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        pulumi.set(__self__, "vswitch_id", vswitch_id)
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> pulumi.Input[builtins.str]:
        """
        Network load balancer id
        """
        return pulumi.get(self, "load_balancer_id")

    @load_balancer_id.setter
    def load_balancer_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "load_balancer_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Input[builtins.str]:
        """
        The list of zones and vSwitch mappings
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vswitch_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Input[builtins.str]:
        """
        ZoneId
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "zone_id", value)


@pulumi.input_type
class _LoadBalancerZoneShiftedAttachmentState:
    def __init__(__self__, *,
                 load_balancer_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering LoadBalancerZoneShiftedAttachment resources.
        :param pulumi.Input[builtins.str] load_balancer_id: Network load balancer id
        :param pulumi.Input[builtins.str] status: Status
        :param pulumi.Input[builtins.str] vswitch_id: The list of zones and vSwitch mappings
        :param pulumi.Input[builtins.str] zone_id: ZoneId
        """
        if load_balancer_id is not None:
            pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Network load balancer id
        """
        return pulumi.get(self, "load_balancer_id")

    @load_balancer_id.setter
    def load_balancer_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "load_balancer_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The list of zones and vSwitch mappings
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vswitch_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ZoneId
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.type_token("alicloud:nlb/loadBalancerZoneShiftedAttachment:LoadBalancerZoneShiftedAttachment")
class LoadBalancerZoneShiftedAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 load_balancer_id: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Network Load Balancer (NLB) Load Balancer Zone Shifted Attachment resource.

        Network load balancer shift zone.

        For information about Network Load Balancer (NLB) Load Balancer Zone Shifted Attachment and how to use it, see [What is Load Balancer Zone Shifted Attachment](https://next.api.alibabacloud.com/document/Nlb/2022-04-30/StartShiftLoadBalancerZones).

        > **NOTE:** Available since v1.245.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        vpc = alicloud.vpc.Network("vpc",
            description="example",
            cidr_block="10.0.0.0/8",
            enable_ipv6=True,
            vpc_name="tf-exampleacc-248")
        vsw1 = alicloud.vpc.Switch("vsw1",
            vpc_id=vpc.id,
            zone_id="cn-beijing-l",
            cidr_block="10.0.1.0/24",
            vswitch_name="tf-exampleacc-41")
        vsw2 = alicloud.vpc.Switch("vsw2",
            vpc_id=vpc.id,
            zone_id="cn-beijing-k",
            cidr_block="10.0.2.0/24",
            vswitch_name="tf-exampleacc-301",
            ipv6_cidr_block_mask=8)
        nlb = alicloud.nlb.LoadBalancer("nlb",
            zone_mappings=[
                {
                    "vswitch_id": vsw1.id,
                    "zone_id": vsw1.zone_id,
                },
                {
                    "vswitch_id": vsw2.id,
                    "zone_id": vsw2.zone_id,
                },
            ],
            vpc_id=vpc.id,
            address_type="Intranet")
        default = alicloud.nlb.LoadBalancerZoneShiftedAttachment("default",
            zone_id=vsw1.zone_id,
            vswitch_id=vsw1.id,
            load_balancer_id=nlb.id)
        ```

        ## Import

        Network Load Balancer (NLB) Load Balancer Zone Shifted Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:nlb/loadBalancerZoneShiftedAttachment:LoadBalancerZoneShiftedAttachment example <load_balancer_id>:<zone_id>:<vswitch_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] load_balancer_id: Network load balancer id
        :param pulumi.Input[builtins.str] vswitch_id: The list of zones and vSwitch mappings
        :param pulumi.Input[builtins.str] zone_id: ZoneId
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LoadBalancerZoneShiftedAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Network Load Balancer (NLB) Load Balancer Zone Shifted Attachment resource.

        Network load balancer shift zone.

        For information about Network Load Balancer (NLB) Load Balancer Zone Shifted Attachment and how to use it, see [What is Load Balancer Zone Shifted Attachment](https://next.api.alibabacloud.com/document/Nlb/2022-04-30/StartShiftLoadBalancerZones).

        > **NOTE:** Available since v1.245.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        vpc = alicloud.vpc.Network("vpc",
            description="example",
            cidr_block="10.0.0.0/8",
            enable_ipv6=True,
            vpc_name="tf-exampleacc-248")
        vsw1 = alicloud.vpc.Switch("vsw1",
            vpc_id=vpc.id,
            zone_id="cn-beijing-l",
            cidr_block="10.0.1.0/24",
            vswitch_name="tf-exampleacc-41")
        vsw2 = alicloud.vpc.Switch("vsw2",
            vpc_id=vpc.id,
            zone_id="cn-beijing-k",
            cidr_block="10.0.2.0/24",
            vswitch_name="tf-exampleacc-301",
            ipv6_cidr_block_mask=8)
        nlb = alicloud.nlb.LoadBalancer("nlb",
            zone_mappings=[
                {
                    "vswitch_id": vsw1.id,
                    "zone_id": vsw1.zone_id,
                },
                {
                    "vswitch_id": vsw2.id,
                    "zone_id": vsw2.zone_id,
                },
            ],
            vpc_id=vpc.id,
            address_type="Intranet")
        default = alicloud.nlb.LoadBalancerZoneShiftedAttachment("default",
            zone_id=vsw1.zone_id,
            vswitch_id=vsw1.id,
            load_balancer_id=nlb.id)
        ```

        ## Import

        Network Load Balancer (NLB) Load Balancer Zone Shifted Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:nlb/loadBalancerZoneShiftedAttachment:LoadBalancerZoneShiftedAttachment example <load_balancer_id>:<zone_id>:<vswitch_id>
        ```

        :param str resource_name: The name of the resource.
        :param LoadBalancerZoneShiftedAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LoadBalancerZoneShiftedAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 load_balancer_id: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LoadBalancerZoneShiftedAttachmentArgs.__new__(LoadBalancerZoneShiftedAttachmentArgs)

            if load_balancer_id is None and not opts.urn:
                raise TypeError("Missing required property 'load_balancer_id'")
            __props__.__dict__["load_balancer_id"] = load_balancer_id
            if vswitch_id is None and not opts.urn:
                raise TypeError("Missing required property 'vswitch_id'")
            __props__.__dict__["vswitch_id"] = vswitch_id
            if zone_id is None and not opts.urn:
                raise TypeError("Missing required property 'zone_id'")
            __props__.__dict__["zone_id"] = zone_id
            __props__.__dict__["status"] = None
        super(LoadBalancerZoneShiftedAttachment, __self__).__init__(
            'alicloud:nlb/loadBalancerZoneShiftedAttachment:LoadBalancerZoneShiftedAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            load_balancer_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None) -> 'LoadBalancerZoneShiftedAttachment':
        """
        Get an existing LoadBalancerZoneShiftedAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] load_balancer_id: Network load balancer id
        :param pulumi.Input[builtins.str] status: Status
        :param pulumi.Input[builtins.str] vswitch_id: The list of zones and vSwitch mappings
        :param pulumi.Input[builtins.str] zone_id: ZoneId
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LoadBalancerZoneShiftedAttachmentState.__new__(_LoadBalancerZoneShiftedAttachmentState)

        __props__.__dict__["load_balancer_id"] = load_balancer_id
        __props__.__dict__["status"] = status
        __props__.__dict__["vswitch_id"] = vswitch_id
        __props__.__dict__["zone_id"] = zone_id
        return LoadBalancerZoneShiftedAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> pulumi.Output[builtins.str]:
        """
        Network load balancer id
        """
        return pulumi.get(self, "load_balancer_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Output[builtins.str]:
        """
        The list of zones and vSwitch mappings
        """
        return pulumi.get(self, "vswitch_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[builtins.str]:
        """
        ZoneId
        """
        return pulumi.get(self, "zone_id")

